# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: directory_service.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x64irectory_service.proto\x12\tdirectory\">\n\x12\x46ileLocationUpdate\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x16\n\x0enode_addresses\x18\x02 \x03(\t\"\x1d\n\tFileQuery\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\"\'\n\rFileLocations\x12\x16\n\x0enode_addresses\x18\x01 \x03(\t\"!\n\x0eUpdateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xaa\x01\n\x10\x44irectoryService\x12P\n\x12UpdateFileLocation\x12\x1d.directory.FileLocationUpdate\x1a\x19.directory.UpdateResponse\"\x00\x12\x44\n\x10GetFileLocations\x12\x14.directory.FileQuery\x1a\x18.directory.FileLocations\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'directory_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FILELOCATIONUPDATE']._serialized_start=38
  _globals['_FILELOCATIONUPDATE']._serialized_end=100
  _globals['_FILEQUERY']._serialized_start=102
  _globals['_FILEQUERY']._serialized_end=131
  _globals['_FILELOCATIONS']._serialized_start=133
  _globals['_FILELOCATIONS']._serialized_end=172
  _globals['_UPDATERESPONSE']._serialized_start=174
  _globals['_UPDATERESPONSE']._serialized_end=207
  _globals['_DIRECTORYSERVICE']._serialized_start=210
  _globals['_DIRECTORYSERVICE']._serialized_end=380
# @@protoc_insertion_point(module_scope)
