# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: p2p_file_system.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15p2p_file_system.proto\x12\x03p2p\"\x1f\n\x0b\x46ileRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\"\x18\n\x08\x46ileData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"+\n\tFileChunk\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"!\n\x0eUploadResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32z\n\x0eP2PFileService\x12\x35\n\nUploadFile\x12\x0e.p2p.FileChunk\x1a\x13.p2p.UploadResponse\"\x00(\x01\x12\x31\n\x0c\x44ownloadFile\x12\x10.p2p.FileRequest\x1a\r.p2p.FileData0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'p2p_file_system_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FILEREQUEST']._serialized_start=30
  _globals['_FILEREQUEST']._serialized_end=61
  _globals['_FILEDATA']._serialized_start=63
  _globals['_FILEDATA']._serialized_end=87
  _globals['_FILECHUNK']._serialized_start=89
  _globals['_FILECHUNK']._serialized_end=132
  _globals['_UPLOADRESPONSE']._serialized_start=134
  _globals['_UPLOADRESPONSE']._serialized_end=167
  _globals['_P2PFILESERVICE']._serialized_start=169
  _globals['_P2PFILESERVICE']._serialized_end=291
# @@protoc_insertion_point(module_scope)
